@@ -2,11 +2,11 @@ import unittest
 import pygtk; pygtk.require("2.0")
 import common
 import tempfile
-from common import gnome
+from common import gnomevfs
 
 class VfsTest(unittest.TestCase):
     def testUri(self):
-        uri=gnome.vfs.URI("http://www.gnome.org/index.html")
+        uri=gnomevfs.URI("http://www.gnome.org/index.html")
         self.assertEqual(uri.scheme, "http")
         self.assertEqual(uri.host_name, "www.gnome.org")
         self.assertEqual(uri.short_name, "index.html")
@@ -16,7 +16,7 @@ class VfsTest(unittest.TestCase):
         written = "Tristitia"
         tmpfile.write(written)
         tmpfile.flush()
-        read = gnome.vfs.read_entire_file("file:" + tmpfile.name)
+        read = gnomevfs.read_entire_file("file:" + tmpfile.name)
         self.assertEqual(read, written)
 
 
